aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorJohn Gilmore <gnu@cygnus>1992-07-04 10:41:16 +0000
committerJohn Gilmore <gnu@cygnus>1992-07-04 10:41:16 +0000
commitbc718e874a91d852bfd49e9d31bb35b4fecd93d1 (patch)
tree4570554b09ea6a0165a25bbb501de2f8b17e149c /include
parenta1f6632789739e08281dd335f6d87a37e036c7ed (diff)
downloadgdb-bc718e874a91d852bfd49e9d31bb35b4fecd93d1.zip
gdb-bc718e874a91d852bfd49e9d31bb35b4fecd93d1.tar.gz
gdb-bc718e874a91d852bfd49e9d31bb35b4fecd93d1.tar.bz2
Regen after bfd/syms.c change: BSF_FILE.
Diffstat (limited to 'include')
-rw-r--r--include/bfd.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/include/bfd.h b/include/bfd.h
index c2e378b..cd9fb44 100644
--- a/include/bfd.h
+++ b/include/bfd.h
@@ -972,7 +972,8 @@ typedef struct symbol_cache_entry
#define BSF_WEAK 0x100000
#define BSF_CTOR 0x200000
- /* This symbol was created to point to a section */
+ /* This symbol was created to point to a section, e.g. ELF's
+ STT_SECTION symbols. */
#define BSF_SECTION_SYM 0x400000
/* The symbol used to be a common symbol, but now it is
@@ -1002,7 +1003,11 @@ typedef struct symbol_cache_entry
/* Signal that the symbol is indirect. The value of the symbol
is a pointer to an undefined asymbol which contains the
name to use instead. */
-#define BSF_INDIRECT 0x4000000
+#define BSF_INDIRECT 0x4000000
+
+ /* BSF_FILE marks symbols that contain a file name. This is used
+ for ELF STT_FILE symbols. */
+#define BSF_FILE 0x08000000
flagword flags;